@@ -2,7 +2,7 @@
 use strict;
 use Benchmark qw(:all);
 
-use threads;
+use threads ();
 use Hash::FieldHash ();
 
 my $HUF;
@@ -25,21 +25,35 @@ print "Hash::FieldHash ", Hash::FieldHash->VERSION, "\n";
 
 
 
-cmpthese timethese -1 => {
+cmpthese timethese -2 => {
 	'H::U::F' => sub{
 		fieldhashes \my(%huf1, %huf2, %huf3);
-		my $o = bless {};
-		$huf1{$o} = 1;
-		$huf2{$o} = 2;
-		$huf3{$o} = 3;
-		threads->new(sub{ $huf1{$o} + $huf2{$o} + $huf3{$o} })->join();
+
+		my @objects;
+		for(1 .. 100){
+			my $o = bless {};
+			$huf1{$o} = 1;
+			$huf2{$o} = 2;
+			$huf3{$o} = 3;
+			push @objects, $o;
+		}
+		for(1 .. 3){
+			threads->new(sub{ my @a = @objects })->join();
+		}
 	},
 	'H::F' => sub{
 		Hash::FieldHash::fieldhashes \my(%hf1, %hf2, %hf3);
-		my $o = bless {};
-		$hf1{$o} = 1;
-		$hf2{$o} = 2;
-		$hf3{$o} = 3;
-		threads->new(sub{ $hf1{$o} + $hf2{$o} + $hf3{$o} })->join();
+
+		my @objects;
+		for(1 .. 100){
+			my $o = bless {};
+			$hf1{$o} = 1;
+			$hf2{$o} = 2;
+			$hf3{$o} = 3;
+			push @objects, $o;
+		}
+		for(1 .. 3){
+			threads->new(sub{ my @a = @objects })->join();
+		}
 	},
 };
